% Create a field from quantities at integration points.
% Input arguments
%     geom     - reference geometry field
%     u        - displacement field
%     dT       - temperature difference field
%     output   - this is what you would assign to the 'output' attribute of
%                the context argument of the material update() method.
%     component- component of the 'output' array: see the material update()
%                method.
% Output argument
%     fld - the new field that can be used to map values the colors
%
function fld = field_from_integration_points(self, ...
        geom, u, dT, output, component)
    gcells = get(self.feblock,'gcells');
    ngcells = length(gcells);
    % Make the inverse map from finite element nodes to gcells
    f2gmap=fenode_to_gcell_map (struct ('gcells',gcells));
    gmap=get (f2gmap,'gcell_map');
    % The nodal data are initialized of the zero
    nvals =0*(1:length(gmap))';
    % Loop over cells to interpolate to nodes
    for i=1:length(gmap)
        idat.component=component;
        idat.sum_inv_dist=0;
        idat.sum_quant_inv_dist=0;
        idat.node_xyz=gather(geom,[i],'values','noreshape');
        idat = inspect_integration_points(self, geom, u, dT, ...
            gmap{i}, struct ('output',output), @idi, idat);
        nvals(i)=idat.sum_quant_inv_dist/idat.sum_inv_dist;
    end
    % Make the field
    fld=field(struct ('name', [output num2str(component)],...
        'data', nvals));
    return;
end

% This is an inverse-distance interpolation inspector. 
function idat=idi(idat, out, xyz, pc)
    d=idat.node_xyz-xyz;
    invd=1/norm(d);
    idat.sum_quant_inv_dist=idat.sum_quant_inv_dist + invd*out(idat.component);
    idat.sum_inv_dist=idat.sum_inv_dist+invd;
    return;
end
