% Constructor of the force intensity class (force per unit volume, be it
% force/length^3, force/length^2, force/length^1, or force/length^0).
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options:
%      magn=vector of magnitudes, dimension must correspond to the
%            dimension of the displacement/geometry fields; may be an array
%            of doubles or a function handle/in-line function with signature
%                     function val=f(xyz)
%
function self = force_intensity (varargin)
    class_name='force_intensity';
    parent = classbase;
    if (nargin == 0)
        self.magn = [];
        self = class(self,class_name,parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            self = arg;
            return;
        else
            options = varargin{1};
            self.magn = options.magn;
            self = class(self,class_name,parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end
