% Constructor
% class represents a zero-dimensional manifold geometric cell  (a point
% in space).
% This class is abstract, i.e. every usable 0-D gcell has to be
% derived from it.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options: same as gcell.
% and volume = 
%   Example: gcell_0_manifold(struct ('id',13,'conn',[21], 'volume',4.5))  creates a cell
%      that is attached to the node 21, has volume of 4.5 units, and gives it the `name' 13.
%
function retobj = gcell_0_manifold (varargin)
    class_name='gcell_0_manifold';
    if (nargin == 0)
        self.volume= 1.0;
        parent=gcell(options);
        retobj = class(self,class_name, parent);
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options=varargin{1}; 
            self.volume = 1.0;
            if isfield(options,'volume')
                self.volume = options.volume;
            end
            parent=gcell(options);
            retobj = class(self,class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end