% Compute the linear, displacement independent, strain-displacement matrix
% for a two-manifold element.
%   Call as:
%      B = Blmat(self, Ndersp, Rm)
%   where
%      self=gcell
%      Ndersp=matrix of spatial derivatives of the basis functions
%          with respect to the local coordinate system Rm.
%      Rm=orthogonal matrix with the unit basis vectors of the local
%         coordinate system as columns.  In this case, only the first two
%         columns matters, as this is a one-dimensional element.
%         size(Rm)= [ndim,ndim], where ndim = Number of spatial dimensions
%         of the embedding space.
% Output:
% B = strain-displacement matrix, size (B) = [3,nfens*dim],
%      where dim = Number of spatial dimensions of
%      the embedding space, and nfens = number of finite element nodes on
%      the element. 
%
function B = Blmat(self, Ndersp, Rm)
    nfens = size(Ndersp, 1);
    dim=length (Rm(:,1));
    B = zeros(3,nfens*dim);
    for i= 1:nfens
        B(:,dim*(i-1)+1:dim*i)=...
        [   Ndersp(i,1) 0; ...
            0           Ndersp(i,2); ...
            Ndersp(i,2) Ndersp(i,1) ]*Rm(:,1:2)';
    end
    return;
end

