% Constructor of the class that represents deformable materials.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options:
% optional parameters
%     rho=mass density (default is 1.0)
%
function retobj = mater_defor(varargin)
    class_name='mater_defor';
    parent=mater;
    if (nargin == 0)
        self.rho = 1.0;
        self.alpha = 0.0;
        retobj = class(self,class_name, parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options =varargin{1};
            rho = 1.0; % mass density
            if isfield(options,'rho')
                rho=options.rho;
            end
            self.rho = rho;
            alpha = 0.0; % thermal expansion coefficient
            if isfield(options,'alpha')
                alpha=options.alpha;
            end
            self.alpha = alpha;
            retobj = class(self,class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end